@@ -12,27 +12,29 @@
 #' If the energy calibration differes for both data set `NA` values are produces that
 #' will be removed from the matrix.
 #'
-#' @param object [RLum.Data.Spectrum-class] (**required**):
-#' S4 object of class `RLum.Data.Spectrum`
+#' @param object [RLum.Data.Spectrum-class] or [RLum.Analysis-class] (**required**):
+#' S4 object of class `RLum.Data.Spectrum`,  `RLum.Analysis`or a [list] of such objects. Other objects in
+#' the list are skipped.
 #'
 #' @param spectral.efficiency [data.frame] (**required**):
 #' Data set containing wavelengths (x-column) and relative spectral response values
-#' (y-column) in percentage
+#' (y-column) (values between 0 and 1). The provided data will be used to correct all spectra if `object` is
+#' a [list]
 #'
-#' @return Returns same object as input ([RLum.Data.Spectrum-class])
+#' @return Returns same object as provided as input
 #'
 #' @note
 #' Please note that the spectral efficiency data from the camera alone may not
 #' sufficiently correct for spectral efficiency of the entire optical system
 #' (e.g., spectrometer, camera ...).
 #'
-#' @section Function version: 0.1.2
+#' @section Function version: 0.2.0
 #'
 #' @author
 #' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS-Université Bordeaux Montaigne (France)\cr
 #' Johannes Friedrich, University of Bayreuth (Germany)
 #'
-#' @seealso [RLum.Data.Spectrum-class]
+#' @seealso [RLum.Data.Spectrum-class], [RLum.Analysis-class]
 #'
 #' @keywords manip
 #'
@@ -50,29 +52,69 @@ apply_EfficiencyCorrection <- function(
   spectral.efficiency
 ){
 
+
+  # self-call -----------------------------------------------------------------------------------
+
+  ##case we have a list
+  if(class(object) == "list"){
+    output_list <- lapply(object, function(o){
+      if(class(o) == "RLum.Data.Spectrum" || class(o) == "RLum.Analysis"){
+        apply_EfficiencyCorrection(object = o, spectral.efficiency = spectral.efficiency)
+
+      }else{
+        warning(paste0("[apply_EfficiencyCorrection()] Skipping ",class(o)," object in input list."), call. = FALSE)
+        return(o)
+      }
+
+    })
+
+    return(output_list)
+
+  }
+
+  ##the case of an RLum.Analysis object
+  if(class(object) == "RLum.Analysis"){
+    object@records <- lapply(object@records, function(o){
+      if(class(o) == "RLum.Data.Spectrum"){
+        apply_EfficiencyCorrection(object = o, spectral.efficiency = spectral.efficiency)
+
+      }else{
+        warning(paste0("[apply_EfficiencyCorrection()] Skipping ",class(o)," object in input list."), call. = FALSE)
+        return(o)
+      }
+
+    })
+
+    return(object)
+
+  }
+
+
+
   # Integrity check -----------------------------------------------------------
 
   ##check if object is of class RLum.Data.Spectrum
-  if(class(object) != "RLum.Data.Spectrum"){
+  if(class(object) != "RLum.Data.Spectrum")
+    stop("[apply_EfficiencyCorrection()] Input object is not of type RLum.Data.Spectrum",call. = FALSE)
 
-    stop("[apply_EfficiencyCorrection()] Input object is not of type RLum.Data.Spectrum")
 
-  }
+  if(class(spectral.efficiency) != "data.frame")
+    stop("[apply_EfficiencyCorrection()] 'spectral.efficiency' is not of type data.frame", call. = FALSE)
 
-  if(class(spectral.efficiency) != "data.frame"){
 
-    stop("[apply_EfficiencyCorrection()] Input object is not of type data.frame")
-
-  }
-
-  ## grep data matrix
+  ## grep data matrix from the input object
   temp.matrix <- as(object, "matrix")
 
   ## grep efficency values
-  temp.efficiency <- as.matrix(spectral.efficiency)
+  temp.efficiency <- as.matrix(spectral.efficiency[,1:2])
+
+  ##test max
+  if(max(temp.efficiency[,2]) > 1)
+    stop("[apply_EfficiencyCorrection()] Relative quantum efficiency values > 1 are not allowed.", call. = FALSE)
 
   # Apply method ------------------------------------------------------------
 
+  ##the interpolation is needed to align the resolution
   #set data for interpolation
   temp.efficiency.x <- as.numeric(row.names(temp.matrix))
 
@@ -97,7 +139,6 @@ apply_EfficiencyCorrection <- function(
 
 
   # Return Output------------------------------------------------------------
-
   temp.output <- set_RLum(
     class = "RLum.Data.Spectrum",
     recordType = object@recordType,
