@@ -1,10 +1,9 @@
-context("convert_Concentration2DoseRate")
-
 test_that("basic checks", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   ## template
-  template <- expect_is(convert_Concentration2DoseRate(), "data.frame")
+  template <- expect_s3_class(convert_Concentration2DoseRate(), "data.frame")
 
   ## break function
   expect_error(convert_Concentration2DoseRate(input = "fail"),
