@@ -1,5 +1,3 @@
-context("fit_OSLLifeTimes()")
-
 ##load example data
 data(ExampleData.TR_OSL, envir = environment())
 
@@ -9,6 +7,7 @@ temp_analysis <- set_RLum("RLum.Analysis", records = temp_list)
 
 test_that("standard check", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   ##trigger errors
   expect_null(fit_OSLLifeTimes(object = "test"))
@@ -49,8 +48,13 @@ test_that("standard check", {
     plot = FALSE,
     n.components = 1), class = "RLum.Results")
 
-
-
+  ##warning for log
+  expect_warning(object = fit_OSLLifeTimes(
+    object = ExampleData.TR_OSL,
+    verbose = FALSE,
+    plot = TRUE,
+    log = "x",
+    n.components = 1), regexp = "log-scale requires x-values > 0, set min xlim to 0.01!")
 
 })
 
